Class: WhoisFreaks::DatabasesThreatFeedApi

Inherits:
Object
  • Object
show all
Defined in:
lib/whoisfreaks/api/databases_threat_feed_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DatabasesThreatFeedApi

Returns a new instance of DatabasesThreatFeedApi.



19
20
21
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#download_threat_feed_malware(opts = {}) ⇒ File

Download the daily malware threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (File)


26
27
28
29
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 26

def download_threat_feed_malware(opts = {})
  data, _status_code, _headers = download_threat_feed_malware_with_http_info(opts)
  data
end

#download_threat_feed_malware_sample(opts = {}) ⇒ File

Download a sample of the malware threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


83
84
85
86
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 83

def download_threat_feed_malware_sample(opts = {})
  data, _status_code, _headers = download_threat_feed_malware_sample_with_http_info(opts)
  data
end

#download_threat_feed_malware_sample_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download a sample of the malware threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 91

def download_threat_feed_malware_sample_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_malware_sample ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/malware/sample'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_malware_sample",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_malware_sample\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_threat_feed_malware_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download the daily malware threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 35

def download_threat_feed_malware_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_malware ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/malware'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'date'] = opts[:'date'] if !opts[:'date'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_malware",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_malware\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_threat_feed_phishing(opts = {}) ⇒ File

Download the daily phishing threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (File)


139
140
141
142
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 139

def download_threat_feed_phishing(opts = {})
  data, _status_code, _headers = download_threat_feed_phishing_with_http_info(opts)
  data
end

#download_threat_feed_phishing_sample(opts = {}) ⇒ File

Download a sample of the phishing threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


196
197
198
199
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 196

def download_threat_feed_phishing_sample(opts = {})
  data, _status_code, _headers = download_threat_feed_phishing_sample_with_http_info(opts)
  data
end

#download_threat_feed_phishing_sample_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download a sample of the phishing threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 204

def download_threat_feed_phishing_sample_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_phishing_sample ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/phishing/sample'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_phishing_sample",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_phishing_sample\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_threat_feed_phishing_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download the daily phishing threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 148

def download_threat_feed_phishing_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_phishing ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/phishing'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'date'] = opts[:'date'] if !opts[:'date'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_phishing",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_phishing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_threat_feed_spam(opts = {}) ⇒ File

Download the daily spam threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (File)


252
253
254
255
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 252

def download_threat_feed_spam(opts = {})
  data, _status_code, _headers = download_threat_feed_spam_with_http_info(opts)
  data
end

#download_threat_feed_spam_sample(opts = {}) ⇒ File

Download a sample of the spam threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


309
310
311
312
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 309

def download_threat_feed_spam_sample(opts = {})
  data, _status_code, _headers = download_threat_feed_spam_sample_with_http_info(opts)
  data
end

#download_threat_feed_spam_sample_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download a sample of the spam threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 317

def download_threat_feed_spam_sample_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_spam_sample ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/spam/sample'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_spam_sample",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_spam_sample\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_threat_feed_spam_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Download the daily spam threat feed (CSV)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :date (String)

    Feed date (yyyy-MM-dd); defaults to latest available

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/whoisfreaks/api/databases_threat_feed_api.rb', line 261

def download_threat_feed_spam_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatabasesThreatFeedApi.download_threat_feed_spam ...'
  end
  # resource path
  local_var_path = '/v3.4/download/threat-feed/spam'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'date'] = opts[:'date'] if !opts[:'date'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DatabasesThreatFeedApi.download_threat_feed_spam",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatabasesThreatFeedApi#download_threat_feed_spam\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end