Class: WhoisFreaks::DomainAvailabilityApi

Inherits:
Object
  • Object
show all
Defined in:
lib/whoisfreaks/api/domain_availability_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DomainAvailabilityApi

Returns a new instance of DomainAvailabilityApi.



19
20
21
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#bulk_domain_availability_v2(api_key, bulk_domain_availability_request, opts = {}) ⇒ BulkDomainAvailabilityV2Response

Bulk Domain Availability Check Two bulk modes. Mode 1: POST domainNames array. Mode 2: POST tld array plus domain query param. Max 100 domains per request. 1 credit per domain checked.

Parameters:

  • api_key (String)

    Your WHOISFreaks API key

  • bulk_domain_availability_request (BulkDomainAvailabilityRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :domain (String)

    Required for TLD-mode bulk check (base domain).

  • :format (String) — default: default to 'json'

Returns:



30
31
32
33
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 30

def bulk_domain_availability_v2(api_key, bulk_domain_availability_request, opts = {})
  data, _status_code, _headers = bulk_domain_availability_v2_with_http_info(api_key, bulk_domain_availability_request, opts)
  data
end

#bulk_domain_availability_v2_with_http_info(api_key, bulk_domain_availability_request, opts = {}) ⇒ Array<(BulkDomainAvailabilityV2Response, Integer, Hash)>

Bulk Domain Availability Check Two bulk modes. Mode 1: POST domainNames array. Mode 2: POST tld array plus domain query param. Max 100 domains per request. 1 credit per domain checked.

Parameters:

  • api_key (String)

    Your WHOISFreaks API key

  • bulk_domain_availability_request (BulkDomainAvailabilityRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :domain (String)

    Required for TLD-mode bulk check (base domain).

  • :format (String) — default: default to 'json'

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 43

def bulk_domain_availability_v2_with_http_info(api_key, bulk_domain_availability_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DomainAvailabilityApi.bulk_domain_availability_v2 ...'
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling DomainAvailabilityApi.bulk_domain_availability_v2"
  end
  # verify the required parameter 'bulk_domain_availability_request' is set
  if @api_client.config.client_side_validation && bulk_domain_availability_request.nil?
    fail ArgumentError, "Missing the required parameter 'bulk_domain_availability_request' when calling DomainAvailabilityApi.bulk_domain_availability_v2"
  end
  allowable_values = ["json", "xml"]
  if @api_client.config.client_side_validation && opts[:'format'] && !allowable_values.include?(opts[:'format'])
    fail ArgumentError, "invalid value for \"format\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v2.0/domain/availability'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'apiKey'] = api_key
  query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil?
  query_params[:'format'] = opts[:'format'] if !opts[:'format'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(bulk_domain_availability_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BulkDomainAvailabilityV2Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DomainAvailabilityApi.bulk_domain_availability_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DomainAvailabilityApi#bulk_domain_availability_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#domain_availability_v2(api_key, domain, opts = {}) ⇒ DomainAvailabilityV2Response

Domain Availability Check with Suggestions Check availability of a single domain and optionally get suggestions across multiple TLDs. 1 credit per domain checked. sug=false checks only the queried domain; sug=true returns up to count (max 100) TLD suggestions.

Parameters:

  • api_key (String)

    Your WHOISFreaks API key

  • domain (String)

    The domain name to check

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sug (Boolean)

    Whether to return TLD suggestions alongside the queried domain. (default to false)

  • :count (Integer)

    Number of TLD suggestions to return when sug=true. Maximum is 100. (default to 5)

  • :format (String) — default: default to 'json'

Returns:



116
117
118
119
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 116

def domain_availability_v2(api_key, domain, opts = {})
  data, _status_code, _headers = domain_availability_v2_with_http_info(api_key, domain, opts)
  data
end

#domain_availability_v2_with_http_info(api_key, domain, opts = {}) ⇒ Array<(DomainAvailabilityV2Response, Integer, Hash)>

Domain Availability Check with Suggestions Check availability of a single domain and optionally get suggestions across multiple TLDs. 1 credit per domain checked. sug=false checks only the queried domain; sug=true returns up to `count` (max 100) TLD suggestions.

Parameters:

  • api_key (String)

    Your WHOISFreaks API key

  • domain (String)

    The domain name to check

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sug (Boolean)

    Whether to return TLD suggestions alongside the queried domain. (default to false)

  • :count (Integer)

    Number of TLD suggestions to return when sug=true. Maximum is 100. (default to 5)

  • :format (String) — default: default to 'json'

Returns:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/whoisfreaks/api/domain_availability_api.rb', line 130

def domain_availability_v2_with_http_info(api_key, domain, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DomainAvailabilityApi.domain_availability_v2 ...'
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling DomainAvailabilityApi.domain_availability_v2"
  end
  # verify the required parameter 'domain' is set
  if @api_client.config.client_side_validation && domain.nil?
    fail ArgumentError, "Missing the required parameter 'domain' when calling DomainAvailabilityApi.domain_availability_v2"
  end
  if @api_client.config.client_side_validation && !opts[:'count'].nil? && opts[:'count'] > 100
    fail ArgumentError, 'invalid value for "opts[:"count"]" when calling DomainAvailabilityApi.domain_availability_v2, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'count'].nil? && opts[:'count'] < 1
    fail ArgumentError, 'invalid value for "opts[:"count"]" when calling DomainAvailabilityApi.domain_availability_v2, must be greater than or equal to 1.'
  end

  allowable_values = ["json", "xml"]
  if @api_client.config.client_side_validation && opts[:'format'] && !allowable_values.include?(opts[:'format'])
    fail ArgumentError, "invalid value for \"format\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v2.0/domain/availability'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'apiKey'] = api_key
  query_params[:'domain'] = domain
  query_params[:'sug'] = opts[:'sug'] if !opts[:'sug'].nil?
  query_params[:'count'] = opts[:'count'] if !opts[:'count'].nil?
  query_params[:'format'] = opts[:'format'] if !opts[:'format'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainAvailabilityV2Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"DomainAvailabilityApi.domain_availability_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DomainAvailabilityApi#domain_availability_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end