Class: WhoisFreaks::Route

Inherits:
Object
  • Object
show all
Defined in:
lib/whoisfreaks/models/route.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Route

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/whoisfreaks/models/route.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `WhoisFreaks::Route` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `WhoisFreaks::Route`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'route')
    self.route = attributes[:'route']
  end

  if attributes.key?(:'description')
    if (value = attributes[:'description']).is_a?(Array)
      self.description = value
    end
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'pingable')
    if (value = attributes[:'pingable']).is_a?(Array)
      self.pingable = value
    end
  end

  if attributes.key?(:'ping_hdl')
    if (value = attributes[:'ping_hdl']).is_a?(Array)
      self.ping_hdl = value
    end
  end

  if attributes.key?(:'holes')
    if (value = attributes[:'holes']).is_a?(Array)
      self.holes = value
    end
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'organizations')
    if (value = attributes[:'organizations']).is_a?(Array)
      self.organizations = value
    end
  end

  if attributes.key?(:'member_of')
    if (value = attributes[:'member_of']).is_a?(Array)
      self.member_of = value
    end
  end

  if attributes.key?(:'inject')
    if (value = attributes[:'inject']).is_a?(Array)
      self.inject = value
    end
  end

  if attributes.key?(:'aggr_mtd')
    self.aggr_mtd = attributes[:'aggr_mtd']
  end

  if attributes.key?(:'aggr_bndry')
    self.aggr_bndry = attributes[:'aggr_bndry']
  end

  if attributes.key?(:'export_comps')
    self.export_comps = attributes[:'export_comps']
  end

  if attributes.key?(:'components')
    self.components = attributes[:'components']
  end

  if attributes.key?(:'remarks')
    if (value = attributes[:'remarks']).is_a?(Array)
      self.remarks = value
    end
  end

  if attributes.key?(:'notify')
    if (value = attributes[:'notify']).is_a?(Array)
      self.notify = value
    end
  end

  if attributes.key?(:'mnt_lower')
    if (value = attributes[:'mnt_lower']).is_a?(Array)
      self.mnt_lower = value
    end
  end

  if attributes.key?(:'mnt_routes')
    if (value = attributes[:'mnt_routes']).is_a?(Array)
      self.mnt_routes = value
    end
  end

  if attributes.key?(:'mnt_by')
    if (value = attributes[:'mnt_by']).is_a?(Array)
      self.mnt_by = value
    end
  end

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'date_updated')
    self.date_updated = attributes[:'date_updated']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end
end

Instance Attribute Details

#aggr_bndryObject

Returns the value of attribute aggr_bndry.



40
41
42
# File 'lib/whoisfreaks/models/route.rb', line 40

def aggr_bndry
  @aggr_bndry
end

#aggr_mtdObject

Returns the value of attribute aggr_mtd.



38
39
40
# File 'lib/whoisfreaks/models/route.rb', line 38

def aggr_mtd
  @aggr_mtd
end

#componentsObject

Returns the value of attribute components.



44
45
46
# File 'lib/whoisfreaks/models/route.rb', line 44

def components
  @components
end

#countryObject

Returns the value of attribute country.



30
31
32
# File 'lib/whoisfreaks/models/route.rb', line 30

def country
  @country
end

#date_createdObject

Returns the value of attribute date_created.



56
57
58
# File 'lib/whoisfreaks/models/route.rb', line 56

def date_created
  @date_created
end

#date_updatedObject

Returns the value of attribute date_updated.



58
59
60
# File 'lib/whoisfreaks/models/route.rb', line 58

def date_updated
  @date_updated
end

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/whoisfreaks/models/route.rb', line 20

def description
  @description
end

#export_compsObject

Returns the value of attribute export_comps.



42
43
44
# File 'lib/whoisfreaks/models/route.rb', line 42

def export_comps
  @export_comps
end

#holesObject

Returns the value of attribute holes.



28
29
30
# File 'lib/whoisfreaks/models/route.rb', line 28

def holes
  @holes
end

#injectObject

Returns the value of attribute inject.



36
37
38
# File 'lib/whoisfreaks/models/route.rb', line 36

def inject
  @inject
end

#member_ofObject

Returns the value of attribute member_of.



34
35
36
# File 'lib/whoisfreaks/models/route.rb', line 34

def member_of
  @member_of
end

#mnt_byObject

Returns the value of attribute mnt_by.



54
55
56
# File 'lib/whoisfreaks/models/route.rb', line 54

def mnt_by
  @mnt_by
end

#mnt_lowerObject

Returns the value of attribute mnt_lower.



50
51
52
# File 'lib/whoisfreaks/models/route.rb', line 50

def mnt_lower
  @mnt_lower
end

#mnt_routesObject

Returns the value of attribute mnt_routes.



52
53
54
# File 'lib/whoisfreaks/models/route.rb', line 52

def mnt_routes
  @mnt_routes
end

#notifyObject

Returns the value of attribute notify.



48
49
50
# File 'lib/whoisfreaks/models/route.rb', line 48

def notify
  @notify
end

#organizationsObject

Returns the value of attribute organizations.



32
33
34
# File 'lib/whoisfreaks/models/route.rb', line 32

def organizations
  @organizations
end

#originObject

Returns the value of attribute origin.



22
23
24
# File 'lib/whoisfreaks/models/route.rb', line 22

def origin
  @origin
end

#ping_hdlObject

Returns the value of attribute ping_hdl.



26
27
28
# File 'lib/whoisfreaks/models/route.rb', line 26

def ping_hdl
  @ping_hdl
end

#pingableObject

Returns the value of attribute pingable.



24
25
26
# File 'lib/whoisfreaks/models/route.rb', line 24

def pingable
  @pingable
end

#remarksObject

Returns the value of attribute remarks.



46
47
48
# File 'lib/whoisfreaks/models/route.rb', line 46

def remarks
  @remarks
end

#routeObject

Returns the value of attribute route.



18
19
20
# File 'lib/whoisfreaks/models/route.rb', line 18

def route
  @route
end

#sourceObject

Returns the value of attribute source.



60
61
62
# File 'lib/whoisfreaks/models/route.rb', line 60

def source
  @source
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/whoisfreaks/models/route.rb', line 340

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = WhoisFreaks.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/whoisfreaks/models/route.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/whoisfreaks/models/route.rb', line 63

def self.attribute_map
  {
    :'route' => :'route',
    :'description' => :'description',
    :'origin' => :'origin',
    :'pingable' => :'pingable',
    :'ping_hdl' => :'ping_hdl',
    :'holes' => :'holes',
    :'country' => :'country',
    :'organizations' => :'organizations',
    :'member_of' => :'member_of',
    :'inject' => :'inject',
    :'aggr_mtd' => :'aggr_mtd',
    :'aggr_bndry' => :'aggr_bndry',
    :'export_comps' => :'export_comps',
    :'components' => :'components',
    :'remarks' => :'remarks',
    :'notify' => :'notify',
    :'mnt_lower' => :'mnt_lower',
    :'mnt_routes' => :'mnt_routes',
    :'mnt_by' => :'mnt_by',
    :'date_created' => :'date_created',
    :'date_updated' => :'date_updated',
    :'source' => :'source'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/whoisfreaks/models/route.rb', line 316

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/whoisfreaks/models/route.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/whoisfreaks/models/route.rb', line 96

def self.openapi_types
  {
    :'route' => :'String',
    :'description' => :'Array<String>',
    :'origin' => :'String',
    :'pingable' => :'Array<String>',
    :'ping_hdl' => :'Array<String>',
    :'holes' => :'Array<String>',
    :'country' => :'String',
    :'organizations' => :'Array<String>',
    :'member_of' => :'Array<String>',
    :'inject' => :'Array<String>',
    :'aggr_mtd' => :'String',
    :'aggr_bndry' => :'String',
    :'export_comps' => :'String',
    :'components' => :'String',
    :'remarks' => :'Array<String>',
    :'notify' => :'Array<String>',
    :'mnt_lower' => :'Array<String>',
    :'mnt_routes' => :'Array<String>',
    :'mnt_by' => :'Array<String>',
    :'date_created' => :'String',
    :'date_updated' => :'String',
    :'source' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/whoisfreaks/models/route.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      route == o.route &&
      description == o.description &&
      origin == o.origin &&
      pingable == o.pingable &&
      ping_hdl == o.ping_hdl &&
      holes == o.holes &&
      country == o.country &&
      organizations == o.organizations &&
      member_of == o.member_of &&
      inject == o.inject &&
      aggr_mtd == o.aggr_mtd &&
      aggr_bndry == o.aggr_bndry &&
      export_comps == o.export_comps &&
      components == o.components &&
      remarks == o.remarks &&
      notify == o.notify &&
      mnt_lower == o.mnt_lower &&
      mnt_routes == o.mnt_routes &&
      mnt_by == o.mnt_by &&
      date_created == o.date_created &&
      date_updated == o.date_updated &&
      source == o.source
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/whoisfreaks/models/route.rb', line 411

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/whoisfreaks/models/route.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/whoisfreaks/models/route.rb', line 309

def hash
  [route, description, origin, pingable, ping_hdl, holes, country, organizations, member_of, inject, aggr_mtd, aggr_bndry, export_comps, components, remarks, notify, mnt_lower, mnt_routes, mnt_by, date_created, date_updated, source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



259
260
261
262
263
# File 'lib/whoisfreaks/models/route.rb', line 259

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
# File 'lib/whoisfreaks/models/route.rb', line 387

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/whoisfreaks/models/route.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



381
382
383
# File 'lib/whoisfreaks/models/route.rb', line 381

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
# File 'lib/whoisfreaks/models/route.rb', line 267

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end