Class: WhoisFreaks::WhoisResponse
- Inherits:
-
Object
- Object
- WhoisFreaks::WhoisResponse
- Defined in:
- lib/whoisfreaks/models/whois_response.rb
Instance Attribute Summary collapse
-
#abuse_contact ⇒ Object
Returns the value of attribute abuse_contact.
-
#administrative_contact ⇒ Object
Returns the value of attribute administrative_contact.
-
#billing_contact ⇒ Object
Returns the value of attribute billing_contact.
-
#create_date ⇒ Object
Returns the value of attribute create_date.
-
#domain_name ⇒ Object
Returns the value of attribute domain_name.
-
#domain_registered ⇒ Object
Returns the value of attribute domain_registered.
-
#domain_registrar ⇒ Object
Returns the value of attribute domain_registrar.
-
#domain_status ⇒ Object
Returns the value of attribute domain_status.
-
#expiry_date ⇒ Object
Returns the value of attribute expiry_date.
-
#name_servers ⇒ Object
Returns the value of attribute name_servers.
-
#query_time ⇒ Object
Returns the value of attribute query_time.
-
#registrant_contact ⇒ Object
Returns the value of attribute registrant_contact.
-
#status ⇒ Object
Returns the value of attribute status.
-
#technical_contact ⇒ Object
Returns the value of attribute technical_contact.
-
#update_date ⇒ Object
Returns the value of attribute update_date.
-
#whois_raw_domain ⇒ Object
Returns the value of attribute whois_raw_domain.
-
#whois_server ⇒ Object
Returns the value of attribute whois_server.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WhoisResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WhoisResponse
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `WhoisFreaks::WhoisResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `WhoisFreaks::WhoisResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] end if attributes.key?(:'query_time') self.query_time = attributes[:'query_time'] end if attributes.key?(:'whois_server') self.whois_server = attributes[:'whois_server'] end if attributes.key?(:'domain_registered') self.domain_registered = attributes[:'domain_registered'] end if attributes.key?(:'create_date') self.create_date = attributes[:'create_date'] end if attributes.key?(:'update_date') self.update_date = attributes[:'update_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'domain_registrar') self.domain_registrar = attributes[:'domain_registrar'] end if attributes.key?(:'registrant_contact') self.registrant_contact = attributes[:'registrant_contact'] end if attributes.key?(:'technical_contact') self.technical_contact = attributes[:'technical_contact'] end if attributes.key?(:'administrative_contact') self.administrative_contact = attributes[:'administrative_contact'] end if attributes.key?(:'billing_contact') self.billing_contact = attributes[:'billing_contact'] end if attributes.key?(:'abuse_contact') self.abuse_contact = attributes[:'abuse_contact'] end if attributes.key?(:'name_servers') if (value = attributes[:'name_servers']).is_a?(Array) self.name_servers = value end end if attributes.key?(:'domain_status') if (value = attributes[:'domain_status']).is_a?(Array) self.domain_status = value end end if attributes.key?(:'whois_raw_domain') self.whois_raw_domain = attributes[:'whois_raw_domain'] end end |
Instance Attribute Details
#abuse_contact ⇒ Object
Returns the value of attribute abuse_contact.
44 45 46 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 44 def abuse_contact @abuse_contact end |
#administrative_contact ⇒ Object
Returns the value of attribute administrative_contact.
40 41 42 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 40 def administrative_contact @administrative_contact end |
#billing_contact ⇒ Object
Returns the value of attribute billing_contact.
42 43 44 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 42 def billing_contact @billing_contact end |
#create_date ⇒ Object
Returns the value of attribute create_date.
28 29 30 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 28 def create_date @create_date end |
#domain_name ⇒ Object
Returns the value of attribute domain_name.
20 21 22 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 20 def domain_name @domain_name end |
#domain_registered ⇒ Object
Returns the value of attribute domain_registered.
26 27 28 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 26 def domain_registered @domain_registered end |
#domain_registrar ⇒ Object
Returns the value of attribute domain_registrar.
34 35 36 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 34 def domain_registrar @domain_registrar end |
#domain_status ⇒ Object
Returns the value of attribute domain_status.
48 49 50 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 48 def domain_status @domain_status end |
#expiry_date ⇒ Object
Returns the value of attribute expiry_date.
32 33 34 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 32 def expiry_date @expiry_date end |
#name_servers ⇒ Object
Returns the value of attribute name_servers.
46 47 48 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 46 def name_servers @name_servers end |
#query_time ⇒ Object
Returns the value of attribute query_time.
22 23 24 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 22 def query_time @query_time end |
#registrant_contact ⇒ Object
Returns the value of attribute registrant_contact.
36 37 38 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 36 def registrant_contact @registrant_contact end |
#status ⇒ Object
Returns the value of attribute status.
18 19 20 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 18 def status @status end |
#technical_contact ⇒ Object
Returns the value of attribute technical_contact.
38 39 40 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 38 def technical_contact @technical_contact end |
#update_date ⇒ Object
Returns the value of attribute update_date.
30 31 32 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 30 def update_date @update_date end |
#whois_raw_domain ⇒ Object
Returns the value of attribute whois_raw_domain.
50 51 52 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 50 def whois_raw_domain @whois_raw_domain end |
#whois_server ⇒ Object
Returns the value of attribute whois_server.
24 25 26 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 24 def whois_server @whois_server end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 275 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = WhoisFreaks.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 53 def self.attribute_map { :'status' => :'status', :'domain_name' => :'domain_name', :'query_time' => :'query_time', :'whois_server' => :'whois_server', :'domain_registered' => :'domain_registered', :'create_date' => :'create_date', :'update_date' => :'update_date', :'expiry_date' => :'expiry_date', :'domain_registrar' => :'domain_registrar', :'registrant_contact' => :'registrant_contact', :'technical_contact' => :'technical_contact', :'administrative_contact' => :'administrative_contact', :'billing_contact' => :'billing_contact', :'abuse_contact' => :'abuse_contact', :'name_servers' => :'name_servers', :'domain_status' => :'domain_status', :'whois_raw_domain' => :'whois_raw_domain' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 251 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 81 def self.openapi_types { :'status' => :'Boolean', :'domain_name' => :'String', :'query_time' => :'String', :'whois_server' => :'String', :'domain_registered' => :'String', :'create_date' => :'String', :'update_date' => :'String', :'expiry_date' => :'String', :'domain_registrar' => :'Registrar', :'registrant_contact' => :'Contact', :'technical_contact' => :'Contact', :'administrative_contact' => :'Contact', :'billing_contact' => :'Contact', :'abuse_contact' => :'Object', :'name_servers' => :'Array<String>', :'domain_status' => :'Array<String>', :'whois_raw_domain' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && domain_name == o.domain_name && query_time == o.query_time && whois_server == o.whois_server && domain_registered == o.domain_registered && create_date == o.create_date && update_date == o.update_date && expiry_date == o.expiry_date && domain_registrar == o.domain_registrar && registrant_contact == o.registrant_contact && technical_contact == o.technical_contact && administrative_contact == o.administrative_contact && billing_contact == o.billing_contact && abuse_contact == o.abuse_contact && name_servers == o.name_servers && domain_status == o.domain_status && whois_raw_domain == o.whois_raw_domain end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 346 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 244 def hash [status, domain_name, query_time, whois_server, domain_registered, create_date, update_date, expiry_date, domain_registrar, registrant_contact, technical_contact, administrative_contact, billing_contact, abuse_contact, name_servers, domain_status, whois_raw_domain].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 199 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
322 323 324 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 322 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 316 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 |
# File 'lib/whoisfreaks/models/whois_response.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |